@@ -1,6 +1,6 @@
 ;;; test-org-capture.el --- Tests for org-capture.el -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2015, 2017  Nicolas Goaziou
+;; Copyright (C) 2015, 2017, 2019  Nicolas Goaziou
 
 ;; Author: Nicolas Goaziou <mail@nicolasgoaziou.fr>
 
@@ -223,7 +223,16 @@
 		 :immediate-finish t))))
 	(org-capture nil "t")
 	(org-capture '(16))
-	(buffer-substring (point) (line-end-position)))))))
+	(buffer-substring (point) (line-end-position))))))
+  ;; Do not raise an error on empty entries.
+  (should
+   (org-test-with-temp-text-in-file ""
+     (let* ((file (buffer-file-name))
+	    (org-capture-templates
+	     `(("t" "Test" entry (file+headline ,file "A") "** "
+		:immediate-finish t))))
+       (org-capture nil "t")
+       (buffer-string)))))
 
 (ert-deftest test-org-capture/item ()
   "Test `item' type in capture template."
@@ -283,6 +292,41 @@
 	(org-capture nil "t")
 	(org-capture-finalize))
       (buffer-string))))
+  ;; If there is no list and `:prepend' is non-nil, insert list at the
+  ;; beginning of the entry, or the beginning of the buffer.  However,
+  ;; preserve properties drawer and planning info, if any.
+  (should
+   (equal
+    "* A\n- X\nSome text\n"
+    (org-test-with-temp-text-in-file "* A\nSome text"
+      (let* ((file (buffer-file-name))
+	     (org-capture-templates
+	      `(("t" "Item" item (file+headline ,file "A") "- X"
+		 :prepend t))))
+	(org-capture nil "t")
+	(org-capture-finalize))
+      (buffer-string))))
+  (should
+   (equal
+    "- X\nText\n"
+    (org-test-with-temp-text-in-file "Text"
+      (let* ((file (buffer-file-name))
+	     (org-capture-templates
+	      `(("t" "Item" item (file ,file) "- X" :prepend t))))
+	(org-capture nil "t")
+	(org-capture-finalize))
+      (buffer-string))))
+  (should
+   (equal
+    "* A\nSCHEDULED: <2012-03-29 Thu>\n- X\nText\n"
+    (org-test-with-temp-text-in-file "* A\nSCHEDULED: <2012-03-29 Thu>\nText"
+      (let* ((file (buffer-file-name))
+	     (org-capture-templates
+	      `(("t" "Item" item (file+headline ,file "A") "- X"
+		 :prepend t))))
+	(org-capture nil "t")
+	(org-capture-finalize))
+      (buffer-string))))
   ;; When `:prepend' is nil, insert new item as the last top-level
   ;; item.
   (should
